@@ -12,12 +12,7 @@ package Prima::Lists;
 
 use strict;
 use warnings;
-use Prima::Const;
-use Prima::Classes;
-use Prima::ScrollBar;
-use Prima::StdBitmap;
-use Prima::IntUtils;
-use Prima::Utils;
+use Prima qw(ScrollBar StdBitmap Utils);
 
 package
     ci;
@@ -27,10 +22,8 @@ eval 'use constant Grid => 1 + MaxId;' unless exists $ci::{Grid};
 }
 
 package Prima::AbstractListViewer;
-use vars qw(@ISA);
-@ISA = qw(Prima::Widget Prima::MouseScroller Prima::GroupScroller Prima::ListBoxUtils);
-
-use Prima::Classes;
+use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::GroupScroller Prima::Widget::ListBoxUtils);
+__PACKAGE__->inherit_core_methods('Prima::Widget::GroupScroller');
 
 {
 my %RNT = (
@@ -51,15 +44,11 @@ sub profile_default
 	my %prf = (
 		align          => ta::Left,
 		autoHeight     => 1,
-		autoHScroll    => 1,
-		autoVScroll    => 1,
-		borderWidth    => 2,
 		extendedSelect => 0,
 		drawGrid       => 1,
 		dragable       => 0,
 		focusedItem    => -1,
 		gridColor      => cl::Black,
-		hScroll        => 0,
 		integralHeight => 0,
 		integralWidth  => 0,
 		itemHeight     => $def-> {font}-> {height},
@@ -69,13 +58,9 @@ sub profile_default
 		offset         => 0,
 		topItem        => 0,
 		scaleChildren  => 0,
-		scrollBarClass => 'Prima::ScrollBar',
-		hScrollBarProfile=>{},
-		vScrollBarProfile=>{},
 		selectable     => 1,
 		selectedItems  => [],
 		vertical       => 1,
-		vScroll        => 1,
 		widgetClass    => wc::ListBox,
 	);
 	@$def{keys %prf} = values %prf;
@@ -103,8 +88,6 @@ sub profile_check_in
 	$p-> { integralWidth} = 1 if
 		! exists $p->{integralWidth} and
 		$multi_column and not($vertical);
-	$p-> {autoHScroll} = 0 if exists $p-> {hScroll};
-	$p-> {autoVScroll} = 0 if exists $p-> {vScroll};
 }
 
 sub init
@@ -113,9 +96,9 @@ sub init
 	for ( qw( lastItem topItem focusedItem))
 		{ $self-> {$_} = -1; }
 	for ( qw(
-		autoHScroll autoVScroll scrollTransaction gridColor dx dy hScroll vScroll
+		scrollTransaction gridColor dx dy 
 		itemWidth offset multiColumn count autoHeight multiSelect
-		extendedSelect borderWidth dragable ))
+		extendedSelect dragable ))
 		{ $self-> {$_} = 0; }
 	for ( qw( drawGrid itemHeight integralWidth integralHeight vertical align))
 		{ $self-> {$_} = 1; }
@@ -123,11 +106,10 @@ sub init
 	my %profile = $self-> SUPER::init(@_);
 	$self-> setup_indents;
 	$self-> {selectedItems} = {} unless $profile{multiSelect};
-	$self->{$_} = $profile{$_} for qw(scrollBarClass hScrollBarProfile vScrollBarProfile);
 	for ( qw(
-		autoHScroll autoVScroll gridColor hScroll vScroll offset multiColumn
+		gridColor offset multiColumn
 		itemHeight autoHeight itemWidth multiSelect extendedSelect integralHeight
-		integralWidth focusedItem topItem selectedItems borderWidth dragable
+		integralWidth focusedItem topItem selectedItems dragable
 		vertical drawGrid align))
 		{ $self-> $_( $profile{ $_}); }
 	$self-> reset;
@@ -2008,8 +1990,8 @@ C<get_item_width>, and C<draw_items>.
 
 =head1 Prima::AbstractListViewer
 
-C<Prima::AbstractListViewer> is a descendant of C<Prima::GroupScroller>,
-and some properties are not described here. See L<Prima::IntUtils/"Prima::GroupScroller">.
+C<Prima::AbstractListViewer> is a descendant of C<Prima::Widget::GroupScroller>,
+and some properties are not described here.
 
 The class provides interface to generic list browsing functionality,
 plus functionality for text-oriented lists. The class is not usable directly.
