@@ -25,13 +25,7 @@ extern "C" {
 
 #define SEVERE_DEBUG
 typedef HANDLE WINHANDLE;
-
-#ifdef __CYGWIN__
-typedef int SOCKETHANDLE;
-#else
 typedef HANDLE SOCKETHANDLE;
-#endif
-
 #undef  HWND_DESKTOP
 #define HWND_DESKTOP         guts. desktop_window
 
@@ -69,7 +63,7 @@ typedef HANDLE SOCKETHANDLE;
 #define WM_EXTERNAL                       ( WM_USER + 17)
 #define WM_HASMATE                        ( WM_USER + 18)
 #define WM_FILE                           ( WM_USER + 19)
-#define WM_CROAK                          ( WM_USER + 20)
+#define WM_FILE_REHASH                    ( WM_USER + 20)
 #define WM_REPAINT_LAYERED                ( WM_USER + 21)
 #define WM_DRAG_RESPONSE                  ( WM_USER + 22)
 #define WM_XMOUSECLICK                    ( WM_USER + 23)
@@ -96,13 +90,10 @@ typedef HANDLE SOCKETHANDLE;
 #define stbGDIMask      0x0F
 #define stbGPBrush      0x10
 
-#define SOCKETS_NONE         ( guts. socket_version == -1)
-#define SOCKETS_AS_HANDLES   ( guts. socket_version == 1)
-#define SOCKETS_NATIVE       ( guts. socket_version == 2)
-
 #define FHT_SOCKET  1
 #define FHT_PIPE    2
 #define FHT_OTHER   3
+#define FHT_STDIN   4
 
 #define apcWarn \
 	if (debug) \
@@ -228,17 +219,10 @@ typedef struct _WinGuts
 	UINT           error_mode;           // SetErrorMode() result
 	DWORD          version;              // GetVersion() cached result
 	Point          cmDOUBLECLK;          // cached SM_CxDOUBLECLK values
-	int            socket_version;       // socket behavior type
-	List           files;                // List of active File objects
 	int            mouse_timer;          // is mouse timer started
 	Bool           popup_active;         // flag to avoid double popup activation
 	Bool           pointer_invisible;
 	HWND           console;              // win32-bound console window
-// socket variables
-	List           sockets;              // List of watchable sockets
-	HANDLE         socket_mutex;         // thread semaphore
-	HANDLE         socket_thread;        // thread id
-	Bool           socket_post_sync;     // semaphore
 	Bool           dont_xlate_message;   // one-time stopper to TranslateMessage() call
 	int            utf8_prepend_0x202D;  // newer windows do automatic bidi conversion, this is to cancel it
 	WCHAR *      (*alloc_utf8_to_wchar_visual)(const char*,int,int*);
@@ -267,7 +251,7 @@ typedef struct _WinGuts
 	HWND           last_mouse_click_source;
 	LPARAM         last_mouse_click_position;
 	unsigned int   last_mouse_click_number;
-	Byte           last_mouse_click_fingerprint; // kmXXX | mbXXX
+	uint32_t       last_mouse_click_fingerprint; // kmXXX | mbXXX
 } WinGuts, *PWinGuts;
 
 typedef struct _WindowData
@@ -295,8 +279,9 @@ typedef struct _MenuItemData
 
 typedef struct _FileData
 {
-	SOCKETHANDLE   object;
+	intptr_t       object;
 	int            type;
+	WINHANDLE      event;
 } FileData;
 
 typedef struct
@@ -679,6 +664,10 @@ extern HBITMAP         std_unchecked_bitmap;
 extern int             time_defs_count;
 extern PItemRegRec     time_defs;
 
+#define MAX_SELECT_HANDLES (MAXIMUM_WAIT_OBJECTS-1)
+extern WINHANDLE       select_handles[MAX_SELECT_HANDLES];
+extern unsigned int    select_n_handles;
+
 LRESULT CALLBACK    generic_app_handler      ( HWND win, UINT  msg, WPARAM mp1, LPARAM mp2);
 LRESULT CALLBACK    generic_frame_handler    ( HWND win, UINT  msg, WPARAM mp1, LPARAM mp2);
 LRESULT CALLBACK    layered_frame_handler    ( HWND win, UINT  msg, WPARAM mp1, LPARAM mp2);
@@ -692,7 +681,6 @@ extern WCHAR *      alloc_utf8_to_wchar_visual( const char * utf8, int length, i
 extern WCHAR *      alloc_ascii_to_wchar( const char * text, int *length);
 extern char *       alloc_wchar_to_utf8( WCHAR * src, int * len );
 extern int          apcUpdateWindow( HWND wnd );
-extern int          arc_completion( double * angleStart, double * angleEnd, int * needFigure);
 extern Bool         add_font_to_hash( const PFont key, const PFont font, Bool addSizeEntry);
 extern char *       cf2name( UINT cf );
 extern void         char2wchar( WCHAR * dest, char * src, int lim);
@@ -720,6 +708,9 @@ extern PList        dnd_clipboard_get_formats();
 extern void         dpi_change(void);
 extern char *       err_msg( DWORD errId, char * buffer);
 extern char *       err_msg_gplus( GpStatus errId, char * buffer);
+extern Bool         file_process_events(int cmd, WPARAM param1, LPARAM param2);
+extern void         file_subsystem_done( void);
+extern Bool         file_subsystem_init( void);
 extern PDCFont      font_alloc( Font * data);
 extern void         font_change( Handle self, Font * font);
 extern void         font_clean( void);
@@ -763,13 +754,14 @@ extern long         palette_match( Handle self, long color);
 extern int          palette_match_color( XLOGPALETTE * lp, long clr, int * diff_factor);
 extern PLinePattern patres_fetch( unsigned char * pattern, int len);
 extern UINT         patres_user( unsigned char * pattern, int len);
+extern Bool         process_file_msg( WINHANDLE src);
 extern Bool         process_msg( MSG * msg);
 extern void         process_transparents( Handle self);
 extern HRGN         region_create( Handle mask);
 extern void         register_mapper_fonts(void);
 extern long         remap_color( long clr, Bool toSystem);
 extern void         reset_system_fonts(void);
-extern void         socket_rehash( void);
+extern void         syshandle_rehash( void);
 extern Bool         select_pen(Handle self);
 extern Bool         select_brush(Handle self);
 extern Bool         select_gp_brush(Handle self);
@@ -783,6 +775,7 @@ extern GpPen*       stylus_gp_get_pen(int line_width, uint32_t color);
 extern HPEN         stylus_get_pen( DWORD style, DWORD line_width, COLORREF color );
 extern HBRUSH       stylus_get_solid_brush( COLORREF color );
 extern void         wchar2char( char * dest, WCHAR * src, int lim);
+extern Bool         yield( Bool wait_for_event );
 
 /* compatibility to MSVC 6 */
 #ifndef GWLP_USERDATA
@@ -822,6 +815,19 @@ my_GetUserPreferredUILanguages(
 	PZZWSTR pwszLanguagesBuffer, PULONG pcchLanguagesBuffer
 );
 
+#ifndef CONSOLE_READ_NOREMOVE
+#define CONSOLE_READ_NOREMOVE   0x0001
+#endif
+
+#ifndef CONSOLE_READ_NOWAIT
+#define CONSOLE_READ_NOWAIT     0x0002
+#endif
+
+Bool
+read_console_input(
+	WINHANDLE hConsoleInput, PINPUT_RECORD lpBuffer, DWORD nLength,
+	LPDWORD lpNumberOfEventsRead, USHORT wFlags
+);
 
 #ifdef __cplusplus
 }
